@@ -1,5 +1,5 @@
 #!/bin/bash
-# Copyright 2019 Google Inc.
+# Copyright 2019 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,21 +14,20 @@
 # limitations under the License.
 
 set -eo pipefail
+# Display commands being run.
+set -x
 
 cd github/google-http-java-client/
 
-# Print out Java
+# Print out Java version
 java -version
-echo $JOB_TYPE
+echo ${JOB_TYPE}
 
-export MAVEN_OPTS="-Xmx1024m -XX:MaxPermSize=128m"
-
-# Installs snapshot artifacts locally. Linkage Monitor uses them.
-mvn install -DskipTests=true -B -V
+mvn install -DskipTests=true -Dmaven.javadoc.skip=true -Dgcloud.download.skip=true -B -V
 
 # Kokoro job cloud-opensource-java/ubuntu/linkage-monitor-gcs creates this JAR
 JAR=linkage-monitor-latest-all-deps.jar
 curl -v -O "https://storage.googleapis.com/cloud-opensource-java-linkage-monitor/${JAR}"
 
 # Fails if there's new linkage errors compared with baseline
-java -jar $JAR com.google.cloud:libraries-bom
+java -jar ${JAR} com.google.cloud:libraries-bom
