@@ -45,9 +45,7 @@ pushd target/site/apidocs
 python3 -m docuploader create-metadata \
   --name ${NAME} \
   --version ${VERSION} \
-  --language java \
-  --github-repository https://github.com/googleapis/google-http-java-client \
-  --issue-tracker https://github.com/googleapis/google-http-java-client/issues \
+  --language java
 
 # upload docs
 python3 -m docuploader upload . \
