@@ -20,24 +20,22 @@ python3 -m pip install gcp-releasetool
 python3 -m releasetool publish-reporter-script > /tmp/publisher-script; source /tmp/publisher-script
 
 source $(dirname "$0")/common.sh
-
+MAVEN_SETTINGS_FILE=$(realpath $(dirname "$0")/../../)/settings.xml
 pushd $(dirname "$0")/../../
 
 setup_environment_secrets
 create_settings_xml_file "settings.xml"
 
-AUTORELEASE="false"
-if [[ -n "${AUTORELEASE_PR}" ]]
-then
-  AUTORELEASE="true"
-fi
-
 mvn clean install deploy -B \
-  --settings settings.xml \
+  --settings ${MAVEN_SETTINGS_FILE} \
   -DperformRelease=true \
   -Dgpg.executable=gpg \
   -Dgpg.passphrase=${GPG_PASSPHRASE} \
-  -Dgpg.homedir=${GPG_HOMEDIR} \
-  -Ddeploy.autorelease=${AUTORELEASE}
-
+  -Dgpg.homedir=${GPG_HOMEDIR}
 
+if [[ -n "${AUTORELEASE_PR}" ]]
+then
+  mvn nexus-staging:release -B \
+    -DperformRelease=true \
+    --settings=settings.xml
+fi
\ No newline at end of file
