@@ -30,6 +30,7 @@ import io.opencensus.trace.Span;
 import io.opencensus.trace.Tracer;
 import java.io.IOException;
 import java.io.InputStream;
+import java.util.Properties;
 import java.util.concurrent.Callable;
 import java.util.concurrent.Executor;
 import java.util.concurrent.Executors;
@@ -53,7 +54,7 @@ public final class HttpRequest {
    *
    * @since 1.8
    */
-  public static final String VERSION = "1.30.0";
+  public static final String VERSION = getVersion();
 
   /**
    * User agent suffix for all requests.
@@ -1013,6 +1014,8 @@ public final class HttpRequest {
         if (!retryOnExecuteIOException
             && (ioExceptionHandler == null
                 || !ioExceptionHandler.handleIOException(this, retryRequest))) {
+          // static analysis shows response is always null here
+          span.end(OpenCensusUtils.getEndSpanOptions(null));
           throw e;
         }
         // Save the exception in case the retries do not work and we need to re-throw it later.
@@ -1199,4 +1202,22 @@ public final class HttpRequest {
       span.putAttribute(key, AttributeValue.stringAttributeValue(value));
     }
   }
+  
+  private static String getVersion() {
+    String version = HttpRequest.class.getPackage().getImplementationVersion();
+    // in a non-packaged environment (local), there's no implementation version to read
+    if (version == null) {
+      // fall back to reading from a properties file - note this value is expected to be cached
+      try (InputStream inputStream = HttpRequest.class.getResourceAsStream("/google-http-client.properties")) {
+        if (inputStream != null) {
+          Properties properties = new Properties();
+          properties.load(inputStream);
+          version = properties.getProperty("google-http-client.version");
+        }
+      } catch (IOException e) {
+        // ignore
+      }
+    }
+    return version;
+  }
 }
